AGENT SKILLS · EQUIPAMENTO DE MISSÃO

Agent Skills úteis classificados pelo uso real

Compare Skills verificados por finalidade, conteúdo do pacote, instalações e evidências da fonte antes de adicioná-los.

ESCOPO DO CATÁLOGO
VERIFICADO
Skills
22.433
repositórios
3444
última sincronização
28 de out. de 2026
22.433 Skills
mohitmishra786
Comunidade

timers-pwm-baremetal

Bare-metal timer and PWM skill. Use when configuring general-purpose timers for PWM, input capture, or periodic ticks without RTOS. Activates on queries about timer prescaler, PWM duty cycle, input capture, or SysTick bare-metal.

Instalações / 1h
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

triton-lang

Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/store, masking, atomics, benchmarking with triton.testing, or integrating kernels into PyTorch. Activates on queries about Triton, tl.constexpr, block pointers, Triton benchmarking, or PyTorch custom ops.

Instalações / 1h
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

uart-serial-baremetal

Bare-metal UART skill for serial console and debug. Use when configuring baud rate, polling or IRQ-driven TX/RX, or integrating DMA with UART. Activates on queries about UART bare-metal, baud BRR, serial printf, or USART interrupt.

Instalações / 1h
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

virtual-memory-paging-and-tlb

Virtual memory skill for paging, page tables, and TLB. Use when explaining page faults, multi-level page tables, TLB behavior, or virtual vs physical addressing. Activates on queries about virtual memory, page table, TLB, page fault, mmap paging, or x86-64 paging.

Instalações / 1h
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

wasm-wasmtime

WebAssembly runtime skill using wasmtime. Use when running WASM modules with wasmtime CLI, working with WASI preview2, using the component model, embedding wasmtime in Rust applications, limiting execution with fuel metering, or debugging WASM with DWARF in wasmtime. Activates on queries about wasmtime, WASI, WASM component model, wasmtime embedding, WIT interfaces, fuel metering, or server-side WebAssembly.

Instalações / 1h
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

zig-build-system

Zig build system skill for multi-file Zig projects. Use when writing or debugging build.zig files, adding executables or libraries, integrating C source files, configuring build-time options, running tests with zig build test, or managing build.zig.zon package manifests. Activates on queries about build.zig, b.addExecutable, addCSourceFiles, b.option, zig build, build.zig.zon, or Zig package management.

Instalações / 1h
1
GitHub Stars
263
Atualizado
27 de jun.
fal-ai-community
Comunidade

fal-models-catalog

Choose the right fal.ai endpoint for a given task. Modality-organized catalog of production endpoint defaults, text-to-image, image-to-image, text-to-video, image-to-video, and more. Use when the user has not named a specific model, or asks "which model for X", "best endpoint for Y", "what should I use for Z".

Instalações / 1h
1
GitHub Stars
253
Atualizado
29 de set.
fal-ai-community
Comunidade

fal-recipes

Use-case-driven multi-step pipelines on fal.ai. Trigger when the user asks for a specific kind of content production rather than a single endpoint call: "make a commercial", "ad creative", "product photography", "cinematic shot", "film look", "character design", "consistent character", "anchor system", "storyboard", "multi-shot", "narrative video", "talking head", "lip sync", "make this person talk", "virtual try-on", "garment transfer", "restore image", "deblur", "denoise", "fix face", "old pho

Instalações / 1h
1
GitHub Stars
253
Atualizado
29 de set.
leonvanzyl
Comunidade

create-upstash-software-factory

Set up a "software factory" that turns labelled GitHub issues into reviewed pull requests, using coding agents (Claude Code, Codex or any other CLI agent) that run in Upstash Box sandboxes and are started by GitHub Actions. Use this whenever someone wants to build, recreate, extend or debug an issue-to-PR pipeline, a pool of background coding agents, "agents that work on my GitHub issues", a label-triggered agent workflow, or anything that combines Upstash Box with coding agents and GitHub, even

Instalações / 1h
1
GitHub Stars
107
Atualizado
19 de out.
leonvanzyl
Comunidade

davinci-resolve-pro-edit

Professionally edit a long-form YouTube recording (talking head, screencast, tutorial) in DaVinci Resolve end to end, with the create-video-shorts editing intelligence carried over to long form and assembled through the davinci-resolve MCP. Reuses or makes a clean foundation cut; gives the first 30-45 s a short-form hook (screen zooms with highlights, punch-ins, luxury-tech graphics with real source captures and motion blur, a split with a head pop-out, keyword pops, music that fades out after t

Instalações / 1h
1
GitHub Stars
107
Atualizado
19 de out.
leonvanzyl
Comunidade

davinci-resolve-video-edit

Cut a DaVinci Resolve talking-head / screencast / tutorial timeline into a clean, well-paced foundation edit - removing bad takes, retakes, false starts, stumbles, "um"/"uh" fillers, lip smacks and noises - using word-level CrisperWhisper 2.0 transcription on the local GPU and the davinci-resolve MCP. Use this whenever the user wants to edit, clean up, tighten or rough-cut a Resolve timeline, remove bad takes/ums/retakes/filler words, "cut this video like a professional editor", or prepare a You

Instalações / 1h
1
GitHub Stars
107
Atualizado
19 de out.
catalystbyzoho
Comunidade

catalyst-authentication

Catalyst Authentication — user login/signup, ZAID, Web SDK auth flows, OAuth token management via Connections, third-party authentication (Okta, Auth0, Duo, custom IdP), social logins (Google, Facebook, LinkedIn, Microsoft), generateCustomToken, signinWithJwt. Trigger on 'authentication', 'login', 'signup', 'getCurrentUser', 'ZAID', 'isUserAuthenticated', 'signOut', 'Connections', 'getAccessToken', 'third-party auth', 'social login', 'Google login', 'signinWithJwt', or 'generateCustomToken'. You

Instalações / 1h
1
GitHub Stars
69
Atualizado
8 de out.
catalystbyzoho
Comunidade

catalyst-basics

Core Catalyst project setup — directory structure, environments, CLI commands, and all Catalyst IDs (Project ID, ZAID, Table ID, Segment ID, Org ID). Trigger on 'start a Catalyst project', 'what is .catalystrc', 'where do I find my Table ID', 'difference between Development and Production', or any Catalyst ID or CLI question.

Instalações / 1h
1
GitHub Stars
69
Atualizado
8 de out.
catalystbyzoho
Comunidade

catalyst-datastore

Catalyst Data Store — relational cloud database with ZCQL, CRUD operations, table permissions, and result pagination. Requires MCP connection — check for CatalystbyZoho tools before any operation. Trigger on 'Data Store', 'ZCQL', 'create table', 'executeZCQLQuery', 'table permissions', 'ROWID', 'boolean column', 'boolean always true', 'truthy string', 'boolean stored as string', or 'DataStore data types'. You MUST load this skill whenever writing code that reads or writes Data Store data — ZCQL

Instalações / 1h
1
GitHub Stars
69
Atualizado
8 de out.
catalystbyzoho
Comunidade

catalyst-functions

Catalyst serverless functions — all 7 types (Basic I/O, Advanced I/O, Event, Cron, Job, Integration, Browser Logic), handler signatures, catalyst-config.json, Security Rules, API Gateway routing, file uploads, busboy, Express middleware, environment variables, function URL, and function testing. Requires MCP connection — check for CatalystbyZoho tools before any operation. Trigger on 'write a function', 'catalyst function', 'API Gateway', 'Security Rules', 'function not found', 'function returns

Instalações / 1h
1
GitHub Stars
69
Atualizado
8 de out.
catalystbyzoho
Comunidade

catalyst-zoho-mcp

Catalyst Zoho MCP — manage Catalyst infrastructure (tables, buckets, cache) via CatalystbyZoho MCP tools using natural language. Trigger on 'Zoho MCP', 'MCP tools', 'catalyst MCP', 'CatalystbyZoho', 'create table with AI', 'MCP setup', 'MCP config', 'global MCP server', 'infrastructure as conversation', 'MCP first', 'avoid Catalyst console', or 'use MCP instead of console'.

Instalações / 1h
1
GitHub Stars
69
Atualizado
8 de out.
orcasecurity
Comunidade

orca-cloud-cost-optimizer

Cloud cost optimization analysis using Orca Security asset data. Discovers all cloud assets (AWS, GCP, Azure) through Orca MCP tools, compares current configurations against cheaper alternatives using live public pricing, and produces a prioritized cost reduction report with exact asset evidence. Use when the user asks about cloud cost optimization, reducing cloud spend, rightsizing instances, saving money on cloud infrastructure, cost reduction opportunities, unused resources, oversized VMs, re

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-compliance-gap

Deep-dive compliance gap analysis for any framework — failing controls ranked by impact, quick wins, account breakdown, and remediation plan. Use when user asks about compliance gaps, failures, or status (e.g., "compliance gaps", "PCI DSS status", "where are we failing", "SOC 2 compliance", "quick wins").

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-config-origin

Traces any Orca alert back to who deployed it, what tool was used, what introduced the issue, and a full timeline of events. Use when user asks about origin, deployment, or ownership of an alert (e.g., "who created this", "where did this come from", "trace back orca-3380725", "who deployed", "what tool was used").

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-cve-blast-radius

CVE blast-radius analysis — given a single CVE-ID, find every affected asset across all accounts, rank by real exposure (internet-facing, attack-path participant, crown jewel) instead of static CVSS. Use when user asks about a specific CVE's environmental impact (e.g., "blast radius of CVE-2024-1234", "where are we affected by Log4Shell", "which assets have CVE-2021-44228", "who is exposed to CVE-XXXX").

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-impact-analysis

Analyzes the full impact of fixing an Orca alert — what closes, what breaks, and what the environment looks like after the fix. Use when user asks about impact, consequences, or blast radius of fixing an alert (e.g., "what's the impact of fixing orca-3380725", "if I fix this what breaks", "what else closes").

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-inactive-identities-cleanup

Inactive-identity cleanup - finds inactive identities (users, groups, and non-human identities) across an account, business unit, or tag in every cloud provider Orca supports (AWS, Azure incl. Entra ID, GCP incl. Google Workspace, Alibaba Cloud, OCI, Tencent Cloud), ranks them by identity risk score (highest risk first), and drives remediation through a non-destructive path (disable) or a destructive path (delete) that always requires explicit confirmation. Asks for the inactivity time frame (e.

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-k8s-connector-troubleshoot

Diagnoses Kubernetes Connector (K8s Tunnel Client / Helm chart orca-tunnel) install and connectivity failures from raw customer input — error text, helm status, kubectl describe, or pod logs — and walks through step-by-step remediation. Use when a user reports the K8s Connector won't install, won't connect, keeps disconnecting, or the cluster shows connected but no scan data appears.

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.
orcasecurity
Comunidade

orca-mfa-enforcement

Finds users who can sign in without MFA across an account, business unit, or tag, ranks them by identity risk, and drives guided enrollment or gated enforcement. Use for MFA or 2FA gaps, root-account MFA, and MFA coverage evidence for an audit.

Instalações / 1h
1
GitHub Stars
55
Atualizado
15 de out.